@@ -42,7 +42,7 @@ use version 0.77;
 
 # PODNAME: Dist::Zilla::PluginBundle::Author::VDB
 # ABSTRACT: VDB's plugin bundle
-our $VERSION = 'v0.9.0'; # VERSION
+our $VERSION = 'v0.10.0'; # VERSION
 
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
@@ -62,8 +62,9 @@ use IPC::System::Simple ();
 use Path::Tiny 0.070    ();
 use Perl::Version       ();
 
-#   Implicitly required module.
+#   `AutoPrereqs` hints: Implicitly required modules.
 use Pod::Weaver::PluginBundle::Author::VDB ();
+use Perl::PrereqScanner::Scanner::Hint     ();
 
 # --------------------------------------------------------------------------------------------------
 
@@ -439,7 +440,7 @@ sub configure {
         ) : (
         ),
 
-        [ 'Manifest::Write' => { # REQUIRE: v0.9.0
+        [ 'Manifest::Write' => { # REQUIRED VERSION: v0.9.0
             # `Manifest::Write` v0.9.0 strictly requires plugin names, not monikers.
             # If a plugin name is added from the bundle, `PluginBundle::Easy` prepends its name
             # with the bundle name (or moniker?).
@@ -467,7 +468,7 @@ sub configure {
         #   File mungers
         #
 
-        [ 'Templates' => { # REQUIRE: v0.5.0 for including `Dist::Zilla::File` objects.
+        [ 'Templates' => { # REQUIRED VERSION: v0.5.0 # for including `Dist::Zilla::File` objects.
             'templates' => [
                 '@Author::VDB/src doc',
                 @{ $self->templates // [] },
@@ -597,7 +598,9 @@ sub configure {
 
         [ 'MinimumPerl' ],
 
-        [ 'AutoPrereqs' ],
+        [ 'AutoPrereqs' => {
+            'extra_scanners' => 'Hint',
+        } ],
 
         #   `Prereqs::AuthorDeps` has a problem:
         #       <https://github.com/dagolden/Dist-Zilla-Plugin-Prereqs-AuthorDeps/issues/1>
@@ -711,7 +714,7 @@ sub configure {
         #   Make sure the distro does not depend on unwanted modules. Unwanted module, for example,
         #   is `Data::Printer`. I use it often for debugging purposes and forget to remove
         #   debugging code.
-        [ 'Hook::BeforeRelease' => 'unwanted deps' => { # REQUIRTE: HHH
+        [ 'Hook::BeforeRelease' => 'unwanted deps' => {
             'hook' => [ q{
                 my @unwanted = (} . $self->_quote( $self->unwanted_modules ) . q{);
                 my %unwanted = map( { $_ => 1 } @unwanted );
@@ -977,7 +980,7 @@ Dist::Zilla::PluginBundle::Author::VDB - VDB's plugin bundle
 
 =head1 VERSION
 
-Version v0.9.0, released on 2015-10-11 20:32 UTC.
+Version v0.10.0, released on 2015-10-22 11:58 UTC.
 
 =head1 WHAT?
 
